@@ -70,7 +70,6 @@ free_window_data (WindowData *data)
 {
 	g_return_if_fail (data != NULL);
 	
-	g_object_unref (data->panel);
 	g_free (data);
 }
 
@@ -93,12 +92,12 @@ on_table_status_message (GucharmapTable *chartable,
 		gtk_statusbar_push (statusbar, data->context_id, message);
 }
 
+static void
 on_table_set_active_char (GucharmapTable *chartable,
 			  gunichar        wc,
 			  GeditWindow    *window)
 {
 	GString *gs;
-	const gchar *temp;
 	const gchar **temps;
 	gint i;
 
